% showPot   display potentials for the Laplace or the Lame Problem in 2D
%    Creates a surface plot of the chosen potential.
%
%    showPot(p,fct,vertices,sxy)
%   
%    Inputs: 
%       p        - Polynomial degree up to which the potential is
%                    calculated
%       fct      - Name of the potential that is diplayed
%       vertices - Vertices of the element for which the potential is
%                     displayed.
%       sxy      - Points at which the potential is evaluated (used for
%                     mehgrid).
%
%    Examples:
%       showPot(3,'potK',[-1,0;1,0],[linspace(0.5,1.5,30); ...
%                                     linspace(-0.5,0.5,30)])

function showPot(p,fct, vertices, sxy)

if(size(sxy,1)==2)
  [X,Y] = meshgrid(sxy(1,:),sxy(2,:));
else
  [X,Y] = meshgrid(sxy(:,1),sxy(:,2));  
end


tmp = feval(fct,vertices,[X(:),Y(:)],p);

Z = tmp(:,p+1);
Z = reshape(Z,size(X));
surf(X,Y,Z);
xlabel('x'); ylabel('y'); zlabel('z');

